bayespy.inference.vmp.nodes.binomial.BinomialDistribution.compute_moments_and_cgf
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.compute_moments_and_cgf